.\" This manpage has been automatically generated by docbook2man 
.\" from a DocBook document.  This tool can be found at:
.\" <http://shell.ipoline.com/~elmert/comp/docbook2X/> 
.\" Please send any bug reports, improvements, comments, patches, 
.\" etc. to Steve Cheng <steve@ggi-project.org>.
.TH "CREATE" "l" "02 July 1999" "SQL - Language Statements" ""
.SH NAME
CREATE VIEW \- Constructs a virtual table
.SH SYNOPSIS
1998-09-21

.nf
CREATE VIEW \fIview\fR
    AS SELECT \fIquery\fR
  
.fi
.SS    "INPUTS"
.PP
.TP
\fB   \fIview\fB \fR
The name of a view to be created.
.TP
\fB   \fIquery\fB \fR
An SQL query which will provide the columns and rows of the view.

Refer to the SELECT statement for more information
about valid arguments.
.SS    "OUTPUTS"
.PP
.TP
\fB   CREATE \fR
The message returned if the view is successfully created.
.TP
\fB       WARN amcreate: "\fIview\fB" relation already exists \fR
This error occurs if the view specified already exists in the database.
.TP
\fB   NOTICE create: attribute named "\fIcolumn\fB" has an unknown type \fR
The view will be created having a column with an unknown type
if you do not specify it. For example, the following command gives
an error:

.nf
	    CREATE VIEW vista AS SELECT 'Hello World'
	   
.fi
whereas this command does not:

.nf
	    CREATE VIEW vista AS SELECT 'Hello World'::text
	   
.fi
.SH   "DESCRIPTION"
.PP
CREATE VIEW will define a view of a table. This view is
not physically materialized. Specifically, a query
rewrite retrieve rule is automatically generated
to support retrieve operations on views.
.SS    "NOTES"
.PP
Use the DROP VIEW statement to drop views.
.SS    "BUGS"
.PP
Currently, views are read only.
.SH   "USAGE"
.PP
Create a view consisting of all Comedy films:

.nf
CREATE VIEW kinds AS
    SELECT *
    FROM films
    WHERE kind = 'Comedy';

SELECT * FROM kinds;

code |title                    |did| date_prod|kind      |len
-----+-------------------------+---+----------+----------+------
UA502|Bananas                  |105|1971-07-13|Comedy    | 01:22
C_701|There's a Girl in my Soup|107|1970-06-11|Comedy    | 01:36
  
.fi
.SH   "COMPATIBILITY"
.PP
.SS    "SQL92"
.PP
SQL92 specifies some additional capabilities for the CREATE VIEW statement:

.nf
CREATE VIEW \fIview\fR [ \fIcolumn\fR [, ...] ]
    AS SELECT \fIexpression\fR [AS \fIcolname\fR] [, ...]
    FROM \fItable\fR
    [ WHERE \fIcondition\fR ]
    [ WITH [ CASCADE | LOCAL ] CHECK OPTION ]
   
.fi
.TP
\fB     \fR
.RS
.TP
\fB   CHECK OPTION \fR
This option is to do with updatable views.
All INSERTs and UPDATEs on the view will be
checked to ensure data satisfy the view-defining
condition. If they do not, the update will be rejected.
.TP
\fB   LOCAL \fR
Check for integrity on this view.
.TP
\fB   CASCADE \fR
Check for integrity on this view and on any dependent
view. CASCADE is assumed if neither CASCADE nor LOCAL is specified.
.RE
