.\" This manpage has been automatically generated by docbook2man 
.\" from a DocBook document.  This tool can be found at:
.\" <http://shell.ipoline.com/~elmert/comp/docbook2X/> 
.\" Please send any bug reports, improvements, comments, patches, 
.\" etc. to Steve Cheng <steve@ggi-project.org>.
.TH "DECLARE" "l" "02 July 1999" "SQL - Language Statements" ""
.SH NAME
DECLARE \- Defines a cursor for table access
.SH SYNOPSIS
1998-09-04

.nf
DECLARE \fIcursor\fR [ BINARY ] [ INSENSITIVE ] [ SCROLL ]
    CURSOR FOR \fIquery\fR
    [ FOR { READ ONLY | UPDATE [ OF \fIcolumn\fR [, ...] ] ]
  
.fi
.SS    "INPUTS"
.PP
.TP
\fB  \fIcursor\fB \fR
The name of the cursor to be used in subsequent FETCH operations..
.TP
\fB  BINARY \fR
Causes the cursor to fetch data in binary
rather than in text format.
.TP
\fB  INSENSITIVE \fR
SQL92 keyword indicating that data retrieved
from the cursor should be unaffected by updates from other processes or cursors.
Since cursor operations occur within transactions
in Postgres this is always the case.
This keyword has no effect.
.TP
\fB  SCROLL \fR
SQL92 keyword indicating that data may be retrieved
in multiple rows per FETCH operation. Since this is allowed at all times
by Postgres this keyword has no effect.
.TP
\fB  \fIquery\fB \fR
An SQL query which will provide the rows to be governed by the
cursor.
Refer to the SELECT statement for further information about
valid arguments.
.TP
\fB  READ ONLY \fR
SQL92 keyword indicating that the cursor will be used
in a readonly mode. Since this is the only cursor access mode
available in Postgres this keyword has no effect.
.TP
\fB  UPDATE \fR
SQL92 keyword indicating that the cursor will be used
to update tables. Since cursor updates are not currently
supported in Postgres this keyword
provokes an informational error message.
.TP
\fB  \fIcolumn\fB \fR
Column(s) to be updated.
Since cursor updates are not currently
supported in Postgres the UPDATE clause
provokes an informational error message.
.SS    "OUTPUTS"
.PP
.TP
\fB  SELECT \fR
The message returned if the SELECT is run successfully.
.TP
\fB    NOTICE BlankPortalAssignName: portal "\fIcursor\fB" already exists \fR
This error occurs if cursor "\fIcursor\fR" is already declared.
.TP
\fBERROR:  Named portals may only be used in begin/end transaction blocks \fR
This error occurs if the cursor is not declared within a transaction block.
.SH   "DESCRIPTION"
.PP
DECLARE allows a user to create cursors, which can be used to retrieve
a small number of rows at a time out of a larger query. Cursors can return
data either in text or in binary foramt.
.PP
Normal cursors return data  in text format, either ASCII or another
encoding scheme depending on how the Postgres
backend was built. Since
data is stored natively in binary format, the system must
do a conversion to produce the text format. In addition,
text formats are often larger in size than the corresponding binary format.
Once the information comes back in text form,  the client
application may have to convert it to a binary format to
manipulate it anyway.
.PP
BINARY cursors give you back the data in the native binary
representation. So binary cursors will tend to be a
little faster since they suffer less conversion overhead.
.PP
As an example, if a query returns a value of one from an integer column,
you would get a string of '1' with a default cursor
whereas with a binary cursor you would get
a 4-byte value equal to control-A ('^A').
.sp
.RS
.B "Caution:"
BINARY cursors should be used carefully. User applications such
as psql are not aware of binary cursors
and expect data to come back in a text format.
.RE
.PP
However, string representation is architecture-neutral whereas binary
representation can differ between different machine architectures.
Therefore, if your client machine and server machine use different
representations (e.g. "big-endian" versus "little-endian"),
you will probably not want your data returned in
binary format.
.sp
.RS
.B "Tip:"
If you intend to display the data in
ASCII,  getting it back in ASCII will save you some
effort on the client side.
.RE
.SS    "NOTES"
.PP
Cursors are only available in transactions.
.PP
Postgres
does not have an explicit \fBOPEN cursor\fR
statement; a cursor is considered to be open when it is declared.
.sp
.RS
.B "Note:"
In SQL92 cursors are only available in
embedded applications. ecpg, the
embedded SQL preprocessor for Postgres,
supports the SQL92 conventions, including those
involving DECLARE and OPEN statements.
.RE
.SH   "USAGE"
.PP
To declare a cursor:

.nf
DECLARE liahona CURSOR
    FOR SELECT * FROM films;
  
.fi
.SH   "COMPATIBILITY"
.PP
.SS    "SQL92"
.PP
SQL92 allows cursors only in embedded SQL
and in modules. Postgres permits cursors to be used
interactively.
SQL92 allows embedded or modular cursors to
update database information.
All Postgres cursors are readonly.
The BINARY keyword is a Postgres extension.
