.\" This manpage has been automatically generated by docbook2man 
.\" from a DocBook document.  This tool can be found at:
.\" <http://shell.ipoline.com/~elmert/comp/docbook2X/> 
.\" Please send any bug reports, improvements, comments, patches, 
.\" etc. to Steve Cheng <steve@ggi-project.org>.
.TH "INSERT" "l" "02 July 1999" "SQL - Language Statements" ""
.SH NAME
INSERT \- Inserts new rows into a table
.SH SYNOPSIS
1998-09-23

.nf
   INSERT INTO \fItable\fR [ ( \fIcolumn\fR [, ...] ) ]
   { VALUES ( \fIexpression\fR [, ...] ) | SELECT \fIquery\fR }
  
.fi
.SS    "INPUTS"
.PP
.TP
\fB      \fItable\fB \fR
The name of an existing table.
.TP
\fB      \fIcolumn\fB \fR
The name of a column in \fItable\fR.
.TP
\fB      \fIexpression\fB \fR
A valid expression or value to assign to \fIcolumn\fR.
.TP
\fB      \fIquery\fB \fR
A valid query. Refer to the SELECT statement for a further description
of valid arguments.
.SS    "OUTPUTS"
.PP
.TP
\fB     INSERT \fIoid\fB 1 \fR
Message returned if only one row was inserted.
\fIoid\fR
is the numeric OID of the inserted row.
.TP
\fB     INSERT 0 \fI#\fB \fR
Message returned if more than one rows were inserted.
\fI#\fR
is the number of rows inserted.
.SH  "DESCRIPTION"
.PP
INSERT allows one to insert new rows into a table. One can insert
a single row at time or several rows as a result of a query.
The columns in the target list may be listed in any order.
In every column not present in the target list will be inserted 
the default value, if column has not a declared default value
it will be assumed as NULL. If the expression for each column
is not of the correct data type, automatic type coercion will be
attempted.
.PP
You must have insert privilege to a table in order to append
to it, as well as select privilege on any table specified
in a WHERE clause.
.SH  "USAGE"
.PP

.nf
		--Insert a single row into table films;
		--(in the second example the column date_prod is omitted 
		--therefore will be stored in it a default value of NULL):
		--
		INSERT INTO films VALUES
		('UA502','Bananas',105,'1971-07-13','Comedy',INTERVAL '82 minute');
		
		INSERT INTO films (code, title, did, date_prod, kind)
		VALUES ('T_601', 'Yojimbo', 106, DATE '1961-06-16', 'Drama');
	  
.fi

.nf
		--Insert a single row into table distributors, note that
		--only column "name" is specified, to the non specified
		--column "did" will be assigned its default value:
		--
		INSERT INTO distributors (name) VALUES ('British Lion');
	  
.fi

.nf
		--Insert several rows into table films from table tmp:
		--
		INSERT INTO films
		SELECT * FROM tmp;
	  
.fi

.nf
		--Insert into arrays:
		--Create an empty 3x3 gameboard for noughts-and-crosses
		--(all of these queries create the same board attribute)
		--(Refer to the \fIPostgreSQL User's Guide\fR for further
		--information about arrays).
		
		INSERT INTO tictactoe (game, board[1:3][1:3])
		    VALUES (1,'{{"","",""},{},{"",""}}');
		INSERT INTO tictactoe (game, board[3][3])
		    VALUES (2,'{}');
		INSERT INTO tictactoe (game, board)
		    VALUES (3,'{{,,},{,,},{,,}}');
	  
.fi
.SH  "COMPATIBILITY"
.PP
.SS    "SQL92"
.PP
The INSERT statement is fully compatible with SQL92.
Possible limitations in features of the 
\fIquery\fR
clause are documented for the SELECT statement.
