.\" This manpage has been automatically generated by docbook2man 
.\" from a DocBook document.  This tool can be found at:
.\" <http://shell.ipoline.com/~elmert/comp/docbook2X/> 
.\" Please send any bug reports, improvements, comments, patches, 
.\" etc. to Steve Cheng <steve@ggi-project.org>.
.TH "REVOKE" "l" "02 July 1999" "SQL - Language Statements" ""
.SH NAME
REVOKE \- Revokes access privilege from a user, a group or all users.
.SH SYNOPSIS
1998-09-24

.nf
REVOKE \fIprivilege\fR [, ...]
    ON \fIobject\fR [, ...]
    FROM { PUBLIC | GROUP \fIER">g\fRBLE> | \fIusername\fR }
  
.fi
.SS    "INPUTS"
.PP
.TP
\fB       \fIprivilege\fB \fR
The possible privileges are:
.TP
\fB       SELECT \fR
Privilege to access all of the columns of a specific
table/view.
.TP
\fB       INSERT \fR
Privilege to insert data into all columns of a
specific table.
.TP
\fB       UPDATE \fR
Privilege to update all columns of a specific
table.
.TP
\fB       DELETE \fR
Privilege to delete rows from a specific table.
.TP
\fB       RULE \fR
Privilege to define rules on table/view.
(See \fBCREATE RULE\fR).
.TP
\fB       ALL \fR
Rescind all privileges.
.TP
\fB       \fIobject\fB \fR
The name of an object from which to revoke access.
The possible objects are:
.RS
.TP 0.2i
\(bu
table 
.TP 0.2i
\(bu
view 
.TP 0.2i
\(bu
sequence
.TP 0.2i
\(bu
index
.RE
.TP
\fB       \fIgroup\fB \fR
The name of a group from whom to revoke privileges.
.TP
\fB       \fIusername\fB \fR
The name of a user from whom revoke privileges. Use the PUBLIC keyword
to specify all users.
.TP
\fB       PUBLIC \fR
Rescind the specified privilege(s) for all users.
.SS    "OUTPUTS"
.PP
.TP
\fB       CHANGE \fR
Message returned if successfully.
.TP
\fB       ERROR \fR
Message returned if object is not available or impossible
to revoke privileges from a group or users.
.SH   "DESCRIPTION"
.PP
REVOKE allows creator of an object to revoke permissions granted
before, from all users (via PUBLIC) or a certain user or group.
.SS    "NOTES"
.PP
Refer to psql \\z command for further information about permissions 
on existing objects:

.nf
Database    = lusitania
+------------------+---------------------------------------------+
|  Relation        |        Grant/Revoke Permissions             |
+------------------+---------------------------------------------+
| mytable          | {"=rw","miriam=arwR","group todos=rw"}      |
+------------------+---------------------------------------------+
Legend:
     uname=arwR -- privileges granted to a user
     group gname=arwR -- privileges granted to a GROUP
     =arwR -- privileges granted to PUBLIC
		  
     r -- SELECT
     w -- UPDATE/DELETE
     a -- INSERT
     R -- RULE
     arwR -- ALL
    
.fi
.sp
.RS
.B "Tip:"
Currently, to create a GROUP you have to insert 
data manually into table pg_group as:

.nf
          
INSERT INTO pg_group VALUES ('todos');
CREATE USER miriam IN GROUP todos;
     
.fi
.RE
.SH   "USAGE"
.PP

.nf
-- revoke insert privilege from all users on table films:
--
REVOKE INSERT ON films FROM PUBLIC;
  
.fi

.nf
  
-- revoke all privileges from user manuel on view kinds:
--
REVOKE ALL ON kinds FROM manuel;
   
.fi
.SH   "COMPATIBILITY"
.SS    "SQL92"
.PP
The SQL92 syntax for \fBREVOKE\fR
has additional capabilities for rescinding
privileges, including those on individual columns in tables:
.TP
\fB         .nf REVOKE { SELECT | DELETE | USAGE | ALL PRIVILEGES } [, ...]     ON \fIobject\fB     FROM { PUBLIC | \fIusername\fB [, ...] } { RESTRICT | CASCADE } REVOKE { INSERT | UPDATE | REFERENCES } [, ...] [ ( \fIcolumn\fB [, ...] ) ]     ON \fIobject\fB     FROM { PUBLIC | \fIusername\fB [, ...] } { RESTRICT | CASCADE }         .fi \fR
Refer to \fBGRANT\fR for details on individual fields.
.TP
\fB         .nf REVOKE GRANT OPTION FOR \fIprivilege\fB [, ...]     ON \fIobject\fB     FROM { PUBLIC | \fIusername\fB [, ...] } { RESTRICT | CASCADE }         .fi \fR
Rescinds authority for a user to grant the specified privilege
to others.
Refer to the \fBGRANT\fR command for details
on individual fields.
.PP
The possible objects are:
